@@ -11,7 +11,7 @@ else:
     __version__ = resources.read_text('atomman', 'VERSION').strip()
 
 # potentials imports
-from potentials import build_lammps_potential, Settings
+from potentials import build_lammps_potential, settings
 
 # atomman imports
 from . import unitconvert
@@ -23,6 +23,7 @@ from .dump import *
 from .dump import __all__ as dump_all
 from .core import *
 from .core import __all__ as core_all
+from . import cluster
 from . import library
 from .library import load_lammps_potential
 from .load import *
